#ifndef LCD_H
#define LCD_H

//******************** (C) D.Buergin *******************************************
//* File Name          : lcd.h
//* Author             : D. Buergin
//* Version            : V1.0
//* Date               : 19-02-2009
//* Description        : Headerfile for lcd.c
//******************************************************************************

//* Includes ------------------------------------------------------------------*

#include "stm32f10x.h"
#include "platform_config.h"
#include "my_delay.h"

//* Private typedef -----------------------------------------------------------*
//* Private define ------------------------------------------------------------*

#define LCD_LINES           4     /**< number of visible lines of the display */
#define LCD_DISP_LENGTH    20     /**< visibles characters per line of the display */
#define LCD_LINE_LENGTH  0x13     /**< internal line length of the display    */
#define LCD_START_LINE1  0x00     /**< DDRAM address of first char of line 1 */
#define LCD_START_LINE2  0x40     /**< DDRAM address of first char of line 2 */
#define LCD_START_LINE3  0x14     /**< DDRAM address of first char of line 3 */
#define LCD_START_LINE4  0x54     /**< DDRAM address of first char of line 4 */
#define LCD_WRAP_LINES      0     /**< 0: no wrap, 1: wrap at end of visibile line */
#define LCD_DDRAM           7     /**< DB7: set DD RAM address */

//* Private macro -------------------------------------------------------------*
//* Private variables ---------------------------------------------------------*
//* Private function prototypes -----------------------------------------------*

extern GPIO_InitTypeDef GPIO_InitStructure;

extern void lcd_init(void);								// Initial LCD
extern void lcd_out_data4(unsigned char);				// Strobe 4-Bit Data to LCD
extern void lcd_write_byte(unsigned char);				// Write 1 Byte Data to LCD
extern void lcd_write_control(unsigned char); 			// Write Instruction
extern void lcd_write_ascii(unsigned char);				// Write LCD Display(ASCII)
extern void lcd_gotoxy(unsigned char, unsigned char);	// Set Position Cursor LCD
extern void lcd_print(char*);							// Print Display to LCD
extern char busy_lcd(void);								// Read Busy LCD Status
extern void enable_lcd(void);	 						// Enable Pulse

#endif
