#ifndef USART_H
#define USART_H

/**
  ******************************************************************************
  * @file    usart.c
  * @author  Daniel Buergin
  * @version V0.3
  * @date    11/10/2009
  * @brief   Usart Library for Cortex M3 Chip
  ******************************************************************************
  * @copy
  *
  * Based on Code from: Peter Fleury <pfleury@gmx.ch>   http://jump.to/fleury
  *
  */

// Includes ------------------------------------------------------------------

#include "stm32f10x.h"
#include "platform_config.h"

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------

#ifndef UART_RX_BUFFER_SIZE
#define UART_RX_BUFFER_SIZE 64
#endif
/** Size of the circular transmit buffer, must be power of 2 */
#ifndef UART_TX_BUFFER_SIZE
#define UART_TX_BUFFER_SIZE 64
#endif

#define UART_FRAME_ERROR      0x0800 // Framing Error by UART 
#define UART_OVERRUN_ERROR    0x0400 // Overrun condition by UART 
#define UART_BUFFER_OVERFLOW  0x0200 // receive ringbuffer overflow 
#define UART_NO_DATA          0x0100 // no receive data available  

// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------

extern void usart1_init(uint16_t);
extern unsigned int usart1_getc(void);
extern void usart1_putc(unsigned char data);
extern void usart1_Xputc(void* p, char data);
extern void usart1_puts(const char *s );
extern void usart1_flush_rxbuffer(void);

#endif
